@@ -3,7 +3,7 @@ from functools import lru_cache
 
 import requests
 
-from api_manager.exeptions import NotConfiguredException
+from api_manager.exceptions import NotConfiguredException
 
 
 @lru_cache(maxsize=None)
